@@ -122,13 +122,13 @@ static GokScannerEffect* m_pEffectsOnDwell;
 #define MAX_HANDLERS 30
 
 /* number of possible calls */
-#define MAX_CALL_NAMES 61
+#define MAX_CALL_NAMES 62
 
 /* names of all the possible effect calls */
 /* This must be in the same order as the enum "CallIds" */
 static gchar ArrayCallNames[MAX_CALL_NAMES][24] ={
-"ChunkerReset", "ChunkerChunkNone", "ChunkerChunkRows", 
-"ChunkerChunkColumns", 
+"ChunkerReset", "ChunkerChunkNone", "ChunkerChunkKeys", 
+"ChunkerChunkRows", "ChunkerChunkColumns", 
 "ChunkerNextChunk", "ChunkerPreviousChunk", 
 "ChunkerNextKey", "ChunkerPreviousKey", 
 "ChunkerKeyUp", 
@@ -2551,6 +2551,26 @@ void gok_scanner_perform_effects (GokScannerEffect* pEffect)
 				EffectCodeReturned = gok_chunker_chunk_none ();
 				break;
 
+			case CALL_CHUNKER_CHUNK_KEYS:
+				if (gok_data_get_setting (pAccessMethod->Name, pEffect->CallParam1, 
+											&param1Rate, NULL) == TRUE)
+				{
+					if (gok_data_get_setting (pAccessMethod->Name, pEffect->CallParam2, 
+												&param2Rate, NULL) == TRUE)
+					{
+						EffectCodeReturned = gok_chunker_chunk_keys (param1Rate, param2Rate); 
+					}
+					else
+					{
+						gok_log_x ("Can't get CHUNKER_KEYS param2 setting: %s!\n", pEffect->pName);
+					}
+				}
+				else
+				{
+					gok_log_x ("Can't get CHUNKER_KEYS param1 setting: %s!\n", pEffect->pName);
+				}
+				break;
+
 			case CALL_CHUNKER_CHUNK_ROWS:
 				if (gok_data_get_setting (pAccessMethod->Name, pEffect->CallParam1, 
 											&param1Rate, NULL) == TRUE)
